@@ -20,10 +20,14 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
 	
 	TOK_UNDEF TOK_TEXT TOK_DQUOTE TOK_SQUOTE TOK_IQUOTE
 	TOK_SIQUOTE TOK_BLANK TOK_ERROR TOK_EOL TOK_COMMENT TOK_EOF
+	TOK_BASH_COMMENT TOK_C_COMMENT TOK_CC_COMMENT
 	NOERR UNCLOSED_DQUOTE UNCLOSED_SQUOTE UNCLOSED_IQUOTE NOCONTEXT
+	UNCLOSED_C_COMMENT
 	TOK_OPT_DEFAULT TOK_OPT_NONE TOK_OPT_NOUNESCAPE
 	TOK_OPT_SIQUOTE TOK_OPT_UNESCAPE TOK_OPT_UNESCAPE_CHARS
-	TOK_OPT_UNESCAPE_LINES TOK_OPT_PASSCOMMENT
+	TOK_OPT_UNESCAPE_LINES TOK_OPT_PASSCOMMENT TOK_OPT_PASS_COMMENT
+	TOK_OPT_UNESCAPE_NQ_LINES TOK_OPT_C_COMMENT TOK_OPT_CC_COMMENT
+	TOK_OPT_NO_BASH_COMMENT TOK_OPT_NO_IQUOTE
 	tokenizer_options
 	tokenizer_new
 	tokenizer_new_strbuf
@@ -41,10 +45,14 @@ our @EXPORT = qw(
 	
 	TOK_UNDEF TOK_TEXT TOK_DQUOTE TOK_SQUOTE TOK_IQUOTE
 	TOK_SIQUOTE TOK_BLANK TOK_ERROR TOK_EOL TOK_COMMENT TOK_EOF
+	TOK_BASH_COMMENT TOK_C_COMMENT TOK_CC_COMMENT
 	NOERR UNCLOSED_DQUOTE UNCLOSED_SQUOTE UNCLOSED_IQUOTE NOCONTEXT
+	UNCLOSED_C_COMMENT
 	TOK_OPT_DEFAULT TOK_OPT_NONE TOK_OPT_NOUNESCAPE
 	TOK_OPT_SIQUOTE TOK_OPT_UNESCAPE TOK_OPT_UNESCAPE_CHARS
-	TOK_OPT_UNESCAPE_LINES TOK_OPT_PASSCOMMENT
+	TOK_OPT_UNESCAPE_LINES TOK_OPT_PASSCOMMENT TOK_OPT_PASS_COMMENT
+	TOK_OPT_UNESCAPE_NQ_LINES TOK_OPT_C_COMMENT TOK_OPT_CC_COMMENT
+	TOK_OPT_NO_BASH_COMMENT TOK_OPT_NO_IQUOTE
 	tokenizer_options
 	tokenizer_new
 	tokenizer_new_strbuf
@@ -53,10 +61,10 @@ our @EXPORT = qw(
 	tokenizer_switch
 	tokenizer_delete
 	tokenizer_flush
-	tokenizer_destroy
+	tokenizer_destroy	
 );
 
-our $VERSION = '0.2.6';
+our $VERSION = '0.4.0';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -257,16 +265,19 @@ Unescape chars & lines.
 
 =item	B<TOK_OPT_UNESCAPE_CHARS>
 
-Unescape chars
+Unescape chars (inside of quotes only)
 
 =item	B<TOK_OPT_UNESCAPE_LINES>
 
-Unescape lines
+Unescape lines (inside of quotes only)
 
 =item	B<TOK_OPT_PASSCOMMENT>
 
 Enable comment passing to user routines.
 
+=item	B<TOK_OPT_UNESCAPE_NQ_LINES>
+
+Unescape lines (outside of quotes). Escaped end of line will not terminate value processing processing. So escaped multiline text will be returned as single line string.
 
 =back
 
@@ -337,11 +348,11 @@ This tokenizer is based on code generated by B<flex> - fast lexical analyzer gen
 
 =head1 AUTHOR
 
-Samuel Behan, E<lt>sam(at)frida.fri.utc.skE<gt>
+Samuel Behan, E<lt>samkob(at)gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003-2004 by Samuel Behan
+Copyright 2003-2006 by Samuel Behan
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms of GNU/GPL v2. 
